Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJean-Luc Peurière <jlp@nerim.net>2004-11-28 15:14:27 +0300
committerJean-Luc Peurière <jlp@nerim.net>2004-11-28 15:14:27 +0300
commitaa6484db8750bb8d10da3f2b52038da2cedb112f (patch)
treedf846e3aae9c1ff30b14280ab0410edd483c0493 /source/creator
parent8e9d54ced08803fb0c64c03bd75c48dd18ccb675 (diff)
cleaning commit
shut the warnings GCC was producing for Os X
Diffstat (limited to 'source/creator')
-rw-r--r--source/creator/creator.c12
1 files changed, 7 insertions, 5 deletions
diff --git a/source/creator/creator.c b/source/creator/creator.c
index 51340b49a5c..acc5f28281b 100644
--- a/source/creator/creator.c
+++ b/source/creator/creator.c
@@ -110,10 +110,12 @@ static void print_help();
static void print_version();
/* defined is ghostwinlay , we can't include carbon here, conflict with DNA */
#ifdef __APPLE
extern int checkAppleVideoCard();
extern void getMacAvailableBounds(short *top, short *left, short *bottom, short *right);
+extern void winlay_get_screensize(int *width_r, int *height_r);
+extern void winlay_process_events(int wait_for_event);
#endif
@@ -127,10 +129,12 @@ char bprogname[FILE_MAXDIR+FILE_MAXFILE]; /* from blenpluginapi:pluginapi.c */
/* Initialise callbacks for the modules that need them */
void setCallbacks(void);
+#ifndef __APPLE__
static void fpe_handler(int sig)
{
// printf("SIGFPE trapped\n");
}
+#endif
/* handling ctrl-c event in console */
static void blender_esc(int sig)
@@ -224,14 +228,12 @@ int main(int argc, char **argv)
argc= 1;
- /* first let us check if we are hardware accelerated and with VRAM >= 16 Mo */
+ /* first let us check if we are hardware accelerated and with VRAM > 16 Mo */
if (checkAppleVideoCard()) {
short top, left, bottom, right;
winlay_get_screensize(&scr_x, &scr_y);
- /* let sneak under topbar
- setprefsize(1, 1, scr_x-2, scr_y-24);*/
getMacAvailableBounds(&top, &left, &bottom, &right);
setprefsize(left +10,scr_y - bottom +10,right-left -20,bottom - 64);
@@ -110,10 +110,12 @@ static void print_help();
static void print_version();
-/* defined is ghostwinlay , we can't include carbon here, conflict with DNA */
-#ifdef __APPLE
+/* defined in ghostwinlay and winlay, we can't include carbon here, conflict with DNA */
+#ifdef __APPLE__
extern int checkAppleVideoCard();
extern void getMacAvailableBounds(short *top, short *left, short *bottom, short *right);